==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/appsync_datasource/AppsyncDatasourceRelationalDatabaseConfig.java <==
package com.hashicorp.cdktf.providers.aws.appsync_datasource;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:51.697Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.appsyncDatasource.AppsyncDatasourceRelationalDatabaseConfig")
@software.amazon.jsii.Jsii.Proxy(AppsyncDatasourceRelationalDatabaseConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AppsyncDatasourceRelationalDatabaseConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * http_endpoint_config block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/appsync_datasource#http_endpoint_config AppsyncDatasource#http_endpoint_config}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig getHttpEndpointConfig() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource#source_type AppsyncDatasource#source_type}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceType() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AppsyncDatasourceRelationalDatabaseConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AppsyncDatasourceRelationalDatabaseConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AppsyncDatasourceRelationalDatabaseConfig> {
        com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig httpEndpointConfig;
        java.lang.String sourceType;

        /**
         * Sets the value of {@link AppsyncDatasourceRelationalDatabaseConfig#getHttpEndpointConfig}
         * @param httpEndpointConfig http_endpoint_config block.
         *                           Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/appsync_datasource#http_endpoint_config AppsyncDatasource#http_endpoint_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpEndpointConfig(com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig httpEndpointConfig) {
            this.httpEndpointConfig = httpEndpointConfig;
            return this;
        }

        /**
         * Sets the value of {@link AppsyncDatasourceRelationalDatabaseConfig#getSourceType}
         * @param sourceType Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource#source_type AppsyncDatasource#source_type}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceType(java.lang.String sourceType) {
            this.sourceType = sourceType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AppsyncDatasourceRelationalDatabaseConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AppsyncDatasourceRelationalDatabaseConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AppsyncDatasourceRelationalDatabaseConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AppsyncDatasourceRelationalDatabaseConfig {
        private final com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig httpEndpointConfig;
        private final java.lang.String sourceType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.httpEndpointConfig = software.amazon.jsii.Kernel.get(this, "httpEndpointConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig.class));
            this.sourceType = software.amazon.jsii.Kernel.get(this, "sourceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpEndpointConfig = builder.httpEndpointConfig;
            this.sourceType = builder.sourceType;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig getHttpEndpointConfig() {
            return this.httpEndpointConfig;
        }

        @Override
        public final java.lang.String getSourceType() {
            return this.sourceType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHttpEndpointConfig() != null) {
                data.set("httpEndpointConfig", om.valueToTree(this.getHttpEndpointConfig()));
            }
            if (this.getSourceType() != null) {
                data.set("sourceType", om.valueToTree(this.getSourceType()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.appsyncDatasource.AppsyncDatasourceRelationalDatabaseConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AppsyncDatasourceRelationalDatabaseConfig.Jsii$Proxy that = (AppsyncDatasourceRelationalDatabaseConfig.Jsii$Proxy) o;

            if (this.httpEndpointConfig != null ? !this.httpEndpointConfig.equals(that.httpEndpointConfig) : that.httpEndpointConfig != null) return false;
            return this.sourceType != null ? this.sourceType.equals(that.sourceType) : that.sourceType == null;
        }

        @Override
        public final int hashCode() {
            int result = this.httpEndpointConfig != null ? this.httpEndpointConfig.hashCode() : 0;
            result = 31 * result + (this.sourceType != null ? this.sourceType.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/appsync_datasource/AppsyncDatasourceRelationalDatabaseConfig.java <==
package com.hashicorp.cdktf.providers.aws.appsync_datasource;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.447Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.appsyncDatasource.AppsyncDatasourceRelationalDatabaseConfig")
@software.amazon.jsii.Jsii.Proxy(AppsyncDatasourceRelationalDatabaseConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AppsyncDatasourceRelationalDatabaseConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * http_endpoint_config block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/appsync_datasource#http_endpoint_config AppsyncDatasource#http_endpoint_config}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig getHttpEndpointConfig() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/appsync_datasource#source_type AppsyncDatasource#source_type}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceType() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AppsyncDatasourceRelationalDatabaseConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AppsyncDatasourceRelationalDatabaseConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AppsyncDatasourceRelationalDatabaseConfig> {
        com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig httpEndpointConfig;
        java.lang.String sourceType;

        /**
         * Sets the value of {@link AppsyncDatasourceRelationalDatabaseConfig#getHttpEndpointConfig}
         * @param httpEndpointConfig http_endpoint_config block.
         *                           Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/appsync_datasource#http_endpoint_config AppsyncDatasource#http_endpoint_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpEndpointConfig(com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig httpEndpointConfig) {
            this.httpEndpointConfig = httpEndpointConfig;
            return this;
        }

        /**
         * Sets the value of {@link AppsyncDatasourceRelationalDatabaseConfig#getSourceType}
         * @param sourceType Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/appsync_datasource#source_type AppsyncDatasource#source_type}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceType(java.lang.String sourceType) {
            this.sourceType = sourceType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AppsyncDatasourceRelationalDatabaseConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AppsyncDatasourceRelationalDatabaseConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AppsyncDatasourceRelationalDatabaseConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AppsyncDatasourceRelationalDatabaseConfig {
        private final com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig httpEndpointConfig;
        private final java.lang.String sourceType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.httpEndpointConfig = software.amazon.jsii.Kernel.get(this, "httpEndpointConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig.class));
            this.sourceType = software.amazon.jsii.Kernel.get(this, "sourceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpEndpointConfig = builder.httpEndpointConfig;
            this.sourceType = builder.sourceType;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.appsync_datasource.AppsyncDatasourceRelationalDatabaseConfigHttpEndpointConfig getHttpEndpointConfig() {
            return this.httpEndpointConfig;
        }

        @Override
        public final java.lang.String getSourceType() {
            return this.sourceType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHttpEndpointConfig() != null) {
                data.set("httpEndpointConfig", om.valueToTree(this.getHttpEndpointConfig()));
            }
            if (this.getSourceType() != null) {
                data.set("sourceType", om.valueToTree(this.getSourceType()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.appsyncDatasource.AppsyncDatasourceRelationalDatabaseConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AppsyncDatasourceRelationalDatabaseConfig.Jsii$Proxy that = (AppsyncDatasourceRelationalDatabaseConfig.Jsii$Proxy) o;

            if (this.httpEndpointConfig != null ? !this.httpEndpointConfig.equals(that.httpEndpointConfig) : that.httpEndpointConfig != null) return false;
            return this.sourceType != null ? this.sourceType.equals(that.sourceType) : that.sourceType == null;
        }

        @Override
        public final int hashCode() {
            int result = this.httpEndpointConfig != null ? this.httpEndpointConfig.hashCode() : 0;
            result = 31 * result + (this.sourceType != null ? this.sourceType.hashCode() : 0);
            return result;
        }
    }
}
